@@ -14,11 +14,14 @@
 -- limitations under the License.
 --
 
--- give PeopleFlows friendlier names
+-- KRCR_PARM_T
+alter table KRCR_PARM_T CHANGE PARM_DTL_TYP_CD CMPNT_CD varchar(100);
+alter table KRCR_PARM_T CHANGE TXT VAL varchar(4000);
+alter table KRCR_PARM_T CHANGE CONS_CD EVAL_OPRTR_CD varchar(1);
 
-update krms_typ_t set nm='Notify PeopleFlow' where typ_id = '1000';
-update krms_typ_t set nm='Route to PeopleFlow' where typ_id = '1001';
+-- KRCR_PARM_DTL_TYP_T to KRCR_CMPNT_T
+RENAME TABLE KRCR_PARM_DTL_TYP_T TO KRCR_CMPNT_T;
+ALTER TABLE KRCR_CMPNT_T CHANGE PARM_DTL_TYP_CD CMPNT_CD VARCHAR(100);
 
--- remove constraint that is preventing compound props from persisting
-
-alter table krms_cmpnd_prop_props_t modify seq_no decimal(5,0) default null;
+-- KRLC_CMP_TYP_T
+alter table KRLC_CMP_TYP_T drop column DOBJ_MAINT_CD_ACTV_IND;
\ No newline at end of file
